@@ -154,13 +154,6 @@ uint8_t
     return 0;
 }
 
-uint8_t
-    TskAutoDb::openImageUtf8(int a_num, const char *const a_images[],
-    TSK_IMG_TYPE_ENUM a_type, unsigned int a_ssize)
-{
-    return openImageUtf8(a_num, a_images, a_type, a_ssize, nullptr);
-}
-
 /**
  * Adds an image to the database.
  *
@@ -191,13 +184,6 @@ uint8_t
 #endif
 }
 
-uint8_t
-    TskAutoDb::openImage(int a_num, const TSK_TCHAR * const a_images[],
-    TSK_IMG_TYPE_ENUM a_type, unsigned int a_ssize)
-{
-    return openImage(a_num, a_images, a_type, a_ssize, nullptr);
-}
-
 /**
 * Adds an image to the database. Requires that m_img_info is already initialized
 *
@@ -226,7 +212,7 @@ TskAutoDb::addImageDetails(const char* deviceId)
    std::string md5 = "";
    std::string sha1 = "";
    std::string collectionDetails = "";
-#if HAVE_LIBEWF
+#if HAVE_LIBEWF 
    if (m_img_info->itype == TSK_IMG_TYPE_EWF_EWF) {
      // @@@ This should really probably be inside of a tsk_img_ method
        IMG_EWF_INFO *ewf_info = (IMG_EWF_INFO *)m_img_info;
@@ -237,13 +223,13 @@ TskAutoDb::addImageDetails(const char* deviceId)
            sha1 = ewf_info->sha1hash;
        }
 
-       collectionDetails = ewf_get_details(ewf_info);
+       collectionDetails = ewf_get_details(ewf_info);   
    }
 #endif
 
     std::string devId;
     if (NULL != deviceId) {
-        devId = deviceId;
+        devId = deviceId; 
     } else {
         devId = "";
     }
@@ -281,7 +267,7 @@ TskAutoDb::addImageDetails(const char* deviceId)
         }
         img_ptrs[i] = img2;
     }
-#else
+#else 
     img_ptrs = m_img_info->images;
 #endif
 
@@ -315,14 +301,6 @@ TSK_FILTER_ENUM TskAutoDb::filterVs(const TSK_VS_INFO * vs_info)
         return TSK_FILTER_STOP;
     }
 
-    // populating cache m_savedVsInfo and ObjectInfo
-    TSK_DB_VS_INFO vs_db;
-    vs_db.objId = m_curImgId;
-    vs_db.offset = vs_info->offset;
-    vs_db.vstype = vs_info->vstype;
-    vs_db.block_size = vs_info->block_size;
-    m_savedVsInfo.push_back(vs_db);
-
     return TSK_FILTER_CONT;
 }
 
@@ -337,7 +315,6 @@ TskAutoDb::filterPool(const TSK_POOL_INFO * pool_info)
             registerError();
             return TSK_FILTER_STOP;
         }
-
         // Save the parent obj ID for the pool
         m_poolOffsetToParentId[pool_info->img_offset] = m_curVolId;
     }
@@ -347,23 +324,10 @@ TskAutoDb::filterPool(const TSK_POOL_INFO * pool_info)
             registerError();
             return TSK_FILTER_STOP;
         }
-
         // Save the parent obj ID for the pool
         m_poolOffsetToParentId[pool_info->img_offset] = m_curImgId;
     }
 
-    // populating cache m_savedVsInfo
-    TSK_DB_VS_INFO vs_db;
-    vs_db.objId = m_curPoolVs;
-    vs_db.offset = pool_info->img_offset;
-    if (pool_info->ctype == TSK_POOL_TYPE_APFS)
-        vs_db.vstype = TSK_VS_TYPE_APFS;
-    if (pool_info->ctype == TSK_POOL_TYPE_LVM)
-        vs_db.vstype = TSK_VS_TYPE_LVM;
-    vs_db.block_size = pool_info->block_size;
-    m_savedVsInfo.push_back(vs_db);
-
-
     // Store the volume system object ID for later use
     m_poolOffsetToVsId[pool_info->img_offset] = m_curPoolVs;
 
@@ -385,7 +349,7 @@ TskAutoDb::addUnallocatedPoolBlocksToDb(size_t & numPool) {
         if (m_poolOffsetToVsId.find(pool_info->img_offset) == m_poolOffsetToVsId.end()) {
             tsk_error_reset();
             tsk_error_set_errno(TSK_ERR_AUTO_DB);
-            tsk_error_set_errstr("Error addUnallocatedPoolBlocksToDb() - could not find volume system object ID for pool at offset %lld", (long long int)pool_info->img_offset);
+            tsk_error_set_errstr("Error addUnallocatedPoolBlocksToDb() - could not find volume system object ID for pool at offset %lld", pool_info->img_offset);
             return TSK_ERR;
         }
         int64_t curPoolVs = m_poolOffsetToVsId[pool_info->img_offset];
@@ -438,12 +402,6 @@ TskAutoDb::filterPoolVol(const TSK_POOL_VOLUME_INFO * pool_vol)
         return TSK_FILTER_STOP;
     }
 
-    TSK_DB_VS_PART_INFO vol_info_db;
-    vol_info_db.objId = m_curPoolVol;
-    snprintf(vol_info_db.desc, TSK_MAX_DB_VS_PART_INFO_DESC_LEN - 1, "%s", pool_vol->desc);
-    vol_info_db.start = pool_vol->block;                      ///< Starting Block number
-    m_savedVsPartInfo.push_back(vol_info_db);
-
     return TSK_FILTER_CONT;
 }
 
@@ -454,24 +412,11 @@ TskAutoDb::filterVol(const TSK_VS_PART_INFO * vs_part)
     m_foundStructure = true;
     m_poolFound = false;
 
-
-
     if (m_db->addVolumeInfo(vs_part, m_curVsId, m_curVolId)) {
         registerError();
         return TSK_FILTER_STOP;
     }
 
-    // Save the volume info for creating unallocated blocks later
-    TSK_DB_VS_PART_INFO vs_part_db;
-    vs_part_db.objId = m_curVolId;
-    vs_part_db.addr = vs_part->addr;
-    vs_part_db.start = vs_part->start;
-    vs_part_db.len = vs_part->len;
-    strncpy(vs_part_db.desc, vs_part->desc, TSK_MAX_DB_VS_PART_INFO_DESC_LEN - 1);
-    vs_part_db.flags = vs_part->flags;
-    m_savedVsPartInfo.push_back(vs_part_db);
-
-
     return TSK_FILTER_CONT;
 }
 
@@ -505,7 +450,7 @@ TskAutoDb::filterFs(TSK_FS_INFO * fs_info)
     }
 
 
-    // We won't hit the root directory on the walk, so open it now
+    // We won't hit the root directory on the walk, so open it now 
     if ((file_root = tsk_fs_file_open(fs_info, NULL, "/")) != NULL) {
         processFile(file_root, "");
         tsk_fs_file_close(file_root);
@@ -515,32 +460,18 @@ TskAutoDb::filterFs(TSK_FS_INFO * fs_info)
 
     // make sure that flags are set to get all files -- we need this to
     // find parent directory
-
+     
     TSK_FS_DIR_WALK_FLAG_ENUM filterFlags = (TSK_FS_DIR_WALK_FLAG_ENUM)
         (TSK_FS_DIR_WALK_FLAG_ALLOC | TSK_FS_DIR_WALK_FLAG_UNALLOC);
 
     //check if to skip processing of FAT orphans
-    if (m_noFatFsOrphans
+    if (m_noFatFsOrphans 
         && TSK_FS_TYPE_ISFAT(fs_info->ftype) ) {
             filterFlags = (TSK_FS_DIR_WALK_FLAG_ENUM) (filterFlags | TSK_FS_DIR_WALK_FLAG_NOORPHAN);
     }
 
     setFileFilterFlags(filterFlags);
 
-
-    // Save the file system info for creating unallocated blocks later
-    TSK_DB_FS_INFO fs_info_db;
-    fs_info_db.objId = m_curFsId;
-    fs_info_db.imgOffset = fs_info->offset;
-    fs_info_db.fType = fs_info->ftype;
-    fs_info_db.block_size = fs_info->block_size;
-    fs_info_db.block_count = fs_info->block_count;
-    fs_info_db.root_inum = fs_info->root_inum;
-    fs_info_db.first_inum = fs_info->first_inum;
-    fs_info_db.last_inum = fs_info->last_inum;
-    m_savedFsInfo.push_back(fs_info_db);
-
-
     return TSK_FILTER_CONT;
 }
 
@@ -567,7 +498,7 @@ TSK_RETVAL_ENUM
 /**
  * Analyzes the open image and adds image info to a database.
  * Does not deal with transactions and such.  Refer to startAddImage()
- * for more control.
+ * for more control. 
  * @returns 1 if a critical error occurred (DB doesn't exist, no file system, etc.), 2 if errors occurred at some point adding files to the DB (corrupt file, etc.), and 0 otherwise.  Errors will have been registered.
  */
 uint8_t TskAutoDb::addFilesInImgToDb()
@@ -581,7 +512,7 @@ uint8_t TskAutoDb::addFilesInImgToDb()
     }
 
     // @@@ This seems bad because we are overriding what the user may
-    // have set. We should remove the public API if we are going to
+    // have set. We should remove the public API if we are going to 
     // override it -- presumably this was added so that we always have
     // unallocated volume space...
     setVolFilterFlags((TSK_VS_PART_FLAG_ENUM) (TSK_VS_PART_FLAG_ALLOC |
@@ -617,7 +548,7 @@ uint8_t TskAutoDb::addFilesInImgToDb()
 
 
 /**
- * Start the process to add image/file metadata to database inside of a transaction.
+ * Start the process to add image/file metadata to database inside of a transaction. 
  * User must call either commitAddImage() to commit the changes,
  * or revertAddImage() to revert them.
  *
@@ -669,7 +600,7 @@ uint8_t
     if (m_imageWriterEnabled) {
         tsk_img_writer_create(m_img_info, m_imageWriterPath);
     }
-
+    
     if (m_addFileSystems) {
         return addFilesInImgToDb();
     } else {
@@ -747,7 +678,7 @@ TskAutoDb::startAddImage(TSK_IMG_INFO * img_info, const char* deviceId)
 
 #ifdef WIN32
 /**
- * Start the process to add image/file metadata to database inside of a transaction.
+ * Start the process to add image/file metadata to database inside of a transaction. 
  * Same functionality as addFilesInImgToDb().  Reverts
  * all changes on error. User must call either commitAddImage() to commit the changes,
  * or revertAddImage() to revert them.
@@ -763,9 +694,9 @@ uint8_t
     TskAutoDb::startAddImage(int numImg, const char *const imagePaths[],
     TSK_IMG_TYPE_ENUM imgType, unsigned int sSize, const char* deviceId)
 {
-    if (tsk_verbose)
+    if (tsk_verbose) 
         tsk_fprintf(stderr, "TskAutoDb::startAddImage_utf8: Starting add image process\n");
-
+   
 
     if (m_db->releaseSavepoint(TSK_ADD_IMAGE_SAVEPOINT) == 0) {
         tsk_error_reset();
@@ -813,14 +744,14 @@ uint8_t
 
 
 /**
- * Cancel the running process.  Will not be handled immediately.
+ * Cancel the running process.  Will not be handled immediately. 
  */
 void
  TskAutoDb::stopAddImage()
 {
     if (tsk_verbose)
         tsk_fprintf(stderr, "TskAutoDb::stopAddImage: Stop request received\n");
-
+    
     m_stopped = true;
     setStopProcessing();
     // flag is checked every time processFile() is called
@@ -857,7 +788,7 @@ int
 }
 
 /**
- * Finish the transaction after the startAddImage is finished.
+ * Finish the transaction after the startAddImage is finished.  
  * @returns Id of the image that was added or -1 on error (error was NOT registered in list)
  */
 int64_t
@@ -901,7 +832,7 @@ TskAutoDb::setTz(std::string tzone)
 TSK_RETVAL_ENUM
 TskAutoDb::processFile(TSK_FS_FILE * fs_file, const char *path)
 {
-
+    
     // Check if the process has been canceled
      if (m_stopped) {
         if (tsk_verbose)
@@ -913,7 +844,7 @@ TskAutoDb::processFile(TSK_FS_FILE * fs_file, const char *path)
      * progress.  If we get a directory, then use its name.  We
      * do this so that when we are searching for orphan files, then
      * we at least show $OrphanFiles as status.  The secondary check
-     * is to grab the parent folder from files once we return back
+     * is to grab the parent folder from files once we return back 
      * into a folder when we are doing our depth-first recursion. */
     if (isDir(fs_file)) {
         m_curDirAddr = fs_file->name->meta_addr;
@@ -929,11 +860,11 @@ TskAutoDb::processFile(TSK_FS_FILE * fs_file, const char *path)
     }
 
     /* process the attributes.  The case of having 0 attributes can occur
-     * with virtual / sparse files and HFS directories.
+     * with virtual / sparse files and HFS directories.  
      * At some point, this can probably be cleaned
-     * up if TSK is more consistent about if there should always be an
+     * up if TSK is more consistent about if there should always be an 
      * attribute or not.  Sometimes, none of the attributes are added
-     * because of their type and we always want to add a reference to
+     * because of their type and we always want to add a reference to 
      * every file. */
     TSK_RETVAL_ENUM retval = TSK_OK;
     m_attributeAdded = false;
@@ -945,18 +876,18 @@ TskAutoDb::processFile(TSK_FS_FILE * fs_file, const char *path)
     if ((retval == TSK_OK) && (m_attributeAdded == false)) {
         retval = insertFileData(fs_file, NULL, path, NULL, TSK_DB_FILES_KNOWN_UNKNOWN);
     }
-
+    
     // reset the file id
     m_curFileId = 0;
 
     if (retval == TSK_STOP)
         return TSK_STOP;
-    else
+    else 
         return TSK_OK;
 }
 
 
-// we return only OK or STOP -- errors are registered only and OK is returned.
+// we return only OK or STOP -- errors are registered only and OK is returned. 
 TSK_RETVAL_ENUM
 TskAutoDb::processAttribute(TSK_FS_FILE * fs_file,
     const TSK_FS_ATTR * fs_attr, const char *path)
@@ -983,7 +914,7 @@ TskAutoDb::processAttribute(TSK_FS_FILE * fs_file,
                 if (retval == -1) {
                     registerError();
                     return TSK_OK;
-                }
+                } 
                 else if (retval) {
                     file_known = TSK_DB_FILES_KNOWN_KNOWN;
                 }
@@ -994,7 +925,7 @@ TskAutoDb::processAttribute(TSK_FS_FILE * fs_file,
                 if (retval == -1) {
                     registerError();
                     return TSK_OK;
-                }
+                } 
                 else if (retval) {
                     file_known = TSK_DB_FILES_KNOWN_KNOWN_BAD;
                 }
@@ -1074,13 +1005,13 @@ TskAutoDb::md5HashAttr(unsigned char md5Hash[16], const TSK_FS_ATTR * fs_attr)
         return 1;
     }
 
-    TSK_MD5_Final(&md, md5Hash);
+    TSK_MD5_Final(md5Hash, &md);
     return 0;
 }
 
 /**
 * Callback invoked per every unallocated block in the filesystem
-* Creates file ranges and file entries
+* Creates file ranges and file entries 
 * A single file entry per consecutive range of blocks
 * @param a_block block being walked
 * @param a_ptr a pointer to an UNALLOC_BLOCK_WLK_TRACK struct
@@ -1113,9 +1044,9 @@ TSK_WALK_RET_ENUM TskAutoDb::fsWalkUnallocBlocksCb(const TSK_FS_BLOCK *a_block,
     }
 
     // this block is not contiguous with the previous one or we've hit the maximum size; create and add a range object
-    const uint64_t rangeStartOffset = unallocBlockWlkTrack->curRangeStart * unallocBlockWlkTrack->fsInfo.block_size
+    const uint64_t rangeStartOffset = unallocBlockWlkTrack->curRangeStart * unallocBlockWlkTrack->fsInfo.block_size 
         + unallocBlockWlkTrack->fsInfo.offset;
-    const uint64_t rangeSizeBytes = (1 + unallocBlockWlkTrack->prevBlock - unallocBlockWlkTrack->curRangeStart)
+    const uint64_t rangeSizeBytes = (1 + unallocBlockWlkTrack->prevBlock - unallocBlockWlkTrack->curRangeStart) 
         * unallocBlockWlkTrack->fsInfo.block_size;
     unallocBlockWlkTrack->ranges.push_back(TSK_DB_FILE_LAYOUT_RANGE(rangeStartOffset, rangeSizeBytes, unallocBlockWlkTrack->nextSequenceNo++));
 
@@ -1134,11 +1065,11 @@ TSK_WALK_RET_ENUM TskAutoDb::fsWalkUnallocBlocksCb(const TSK_FS_BLOCK *a_block,
         unallocBlockWlkTrack->prevBlock = a_block->addr;
         return TSK_WALK_CONT;
     }
-
+    
     // at this point we are either chunking and have reached the chunk limit
     // or we're not chunking. Either way we now add what we've got to the DB
     int64_t fileObjId = 0;
-    if (unallocBlockWlkTrack->tskAutoDb.m_db->addUnallocBlockFile(unallocBlockWlkTrack->tskAutoDb.m_curUnallocDirId,
+    if (unallocBlockWlkTrack->tskAutoDb.m_db->addUnallocBlockFile(unallocBlockWlkTrack->tskAutoDb.m_curUnallocDirId, 
         unallocBlockWlkTrack->fsObjId, unallocBlockWlkTrack->size, unallocBlockWlkTrack->ranges, fileObjId, unallocBlockWlkTrack->tskAutoDb.m_curImgId) == TSK_ERR) {
             // @@@ Handle error -> Don't have access to registerError() though...
     }
@@ -1152,7 +1083,7 @@ TSK_WALK_RET_ENUM TskAutoDb::fsWalkUnallocBlocksCb(const TSK_FS_BLOCK *a_block,
 
     //we don't know what the last unalloc block is in advance
     //and will handle the last range in addFsInfoUnalloc()
-
+    
     return TSK_WALK_CONT;
 }
 
@@ -1163,7 +1094,7 @@ TSK_WALK_RET_ENUM TskAutoDb::fsWalkUnallocBlocksCb(const TSK_FS_BLOCK *a_block,
 * @param dbFsInfo fs to process
 * @returns TSK_OK on success, TSK_ERR on error
 */
-TSK_RETVAL_ENUM TskAutoDb::addFsInfoUnalloc(const TSK_IMG_INFO*  curImgInfo, const TSK_DB_FS_INFO & dbFsInfo) {
+TSK_RETVAL_ENUM TskAutoDb::addFsInfoUnalloc(const TSK_DB_FS_INFO & dbFsInfo) {
 
     // Unalloc space is handled separately for APFS
     if (dbFsInfo.fType == TSK_FS_TYPE_APFS) {
@@ -1171,7 +1102,7 @@ TSK_RETVAL_ENUM TskAutoDb::addFsInfoUnalloc(const TSK_IMG_INFO*  curImgInfo, con
     }
 
     //open the fs we have from database
-    TSK_FS_INFO * fsInfo = tsk_fs_open_img_decrypt((TSK_IMG_INFO*)curImgInfo, dbFsInfo.imgOffset, dbFsInfo.fType, getFileSystemPassword().data());
+    TSK_FS_INFO * fsInfo = tsk_fs_open_img_decrypt(m_img_info, dbFsInfo.imgOffset, dbFsInfo.fType, getFileSystemPassword().data());
     if (fsInfo == NULL) {
         tsk_error_set_errstr2("TskAutoDb::addFsInfoUnalloc: error opening fs at offset %" PRIdOFF, dbFsInfo.imgOffset);
         registerError();
@@ -1186,9 +1117,9 @@ TSK_RETVAL_ENUM TskAutoDb::addFsInfoUnalloc(const TSK_IMG_INFO*  curImgInfo, con
     }
 
     //walk unalloc blocks on the fs and process them
-    //initialize the unalloc block walk tracking
+    //initialize the unalloc block walk tracking 
     UNALLOC_BLOCK_WLK_TRACK unallocBlockWlkTrack(*this, *fsInfo, dbFsInfo.objId, m_minChunkSize, m_maxChunkSize);
-    uint8_t block_walk_ret = tsk_fs_block_walk(fsInfo, fsInfo->first_block, fsInfo->last_block, (TSK_FS_BLOCK_WALK_FLAG_ENUM)(TSK_FS_BLOCK_WALK_FLAG_UNALLOC | TSK_FS_BLOCK_WALK_FLAG_AONLY),
+    uint8_t block_walk_ret = tsk_fs_block_walk(fsInfo, fsInfo->first_block, fsInfo->last_block, (TSK_FS_BLOCK_WALK_FLAG_ENUM)(TSK_FS_BLOCK_WALK_FLAG_UNALLOC | TSK_FS_BLOCK_WALK_FLAG_AONLY), 
         fsWalkUnallocBlocksCb, &unallocBlockWlkTrack);
 
     if (block_walk_ret == 1) {
@@ -1218,11 +1149,11 @@ TSK_RETVAL_ENUM TskAutoDb::addFsInfoUnalloc(const TSK_IMG_INFO*  curImgInfo, con
         tsk_fs_close(fsInfo);
         return TSK_ERR;
     }
-
-    //cleanup
+    
+    //cleanup 
     tsk_fs_close(fsInfo);
 
-    return TSK_OK;
+    return TSK_OK; 
 }
 
 /**
@@ -1247,8 +1178,8 @@ TSK_RETVAL_ENUM TskAutoDb::addUnallocSpaceToDb() {
     if (numVsP == 0 && numFs == 0 && numPool == 0) {
         retImgFile = addUnallocImageSpaceToDb();
     }
-
-
+    
+    
     if (retFsSpace == TSK_ERR || retVsSpace == TSK_ERR || retPoolSpace == TSK_ERR || retImgFile == TSK_ERR)
         return TSK_ERR;
     else
@@ -1257,253 +1188,43 @@ TSK_RETVAL_ENUM TskAutoDb::addUnallocSpaceToDb() {
 
 
 /**
-* Process each file system in the database and add its unallocated sectors to virtual files.
-* @param numFs (out) number of filesystems found
-* @returns TSK_OK on success, TSK_ERR on error (if some or all fs could not be processed)
-*/
-TSK_RETVAL_ENUM TskAutoDb::getVsPartById(int64_t objId, TSK_VS_PART_INFO & vsPartInfo){
-    for (vector<TSK_DB_VS_PART_INFO>::iterator curVsPartDbInfo = m_savedVsPartInfo.begin(); curVsPartDbInfo!= m_savedVsPartInfo.end(); ++curVsPartDbInfo) {
-        if (curVsPartDbInfo->objId == objId){
-            vsPartInfo.start = curVsPartDbInfo->start;
-            vsPartInfo.desc = curVsPartDbInfo->desc;
-            vsPartInfo.flags = curVsPartDbInfo->flags;
-            vsPartInfo.len = curVsPartDbInfo->len;
-
-            return TSK_OK;
-        }
-    }
-    return TSK_ERR;
-}
-
-TSK_RETVAL_ENUM TskAutoDb::getVsByFsId(int64_t objId, TSK_DB_VS_INFO & vsDbInfo){
-    TSK_DB_OBJECT fsObjDbInfo;
-    if ( m_db->getObjectInfo( objId, fsObjDbInfo) == TSK_OK){ //searches for fs object
-        for (vector<TSK_DB_VS_PART_INFO>::iterator curVsPartDbInfo = m_savedVsPartInfo.begin(); curVsPartDbInfo!= m_savedVsPartInfo.end(); ++curVsPartDbInfo) { //searches for vspart parent of fs
-            if (fsObjDbInfo.parObjId == curVsPartDbInfo->objId){
-                TSK_DB_OBJECT vsPartObjDbInfo;
-                if ( m_db->getObjectInfo(curVsPartDbInfo->objId, vsPartObjDbInfo ) == TSK_OK){
-                    for (vector<TSK_DB_VS_INFO>::iterator curVsDbInfo = m_savedVsInfo.begin(); curVsDbInfo!= m_savedVsInfo.end(); ++curVsDbInfo) { //searches for vs parent of vspart
-                        if (vsPartObjDbInfo.parObjId == curVsDbInfo->objId){
-                            vsDbInfo.objId = curVsDbInfo->objId;
-                            vsDbInfo.block_size = curVsDbInfo->block_size;
-                            vsDbInfo.vstype = curVsDbInfo->vstype;
-                            vsDbInfo.offset = curVsDbInfo->offset;
-                            return TSK_OK;
-                        }
-                    }
-                    if (tsk_verbose) {
-                        tsk_fprintf(stderr, "TskAutoDb:: GetVsByFsId: error getting VS from FS. (Parent VS not Found)");
-                    }
-                    return TSK_ERR;
-                }
-            }
-        }
-        if (tsk_verbose) {
-                tsk_fprintf(stderr, "TskAutoDb:: GetVsByFsId: error getting VS from FS (Parent VS_Part not found)");
-        }
-        return TSK_ERR;
-    }
-    else {
-        if (tsk_verbose) {
-                tsk_fprintf(stderr, "TskAutoDb:: GetVsByFsId: error getting VS from FS (FS object not found)\n");
-        }
-        return TSK_ERR;
-    }
-}
-
-
-/**
-* Process each file system in the database and add its unallocated sectors to virtual files.
+* Process each file system in the database and add its unallocated sectors to virtual files. 
 * @param numFs (out) number of filesystems found
 * @returns TSK_OK on success, TSK_ERR on error (if some or all fs could not be processed)
 */
 TSK_RETVAL_ENUM TskAutoDb::addUnallocFsSpaceToDb(size_t & numFs) {
 
+    vector<TSK_DB_FS_INFO> fsInfos;
+
     if(m_stopAllProcessing) {
         return TSK_OK;
     }
 
-    numFs = m_savedFsInfo.size();
-    TSK_RETVAL_ENUM allFsProcessRet = TSK_OK;
-
-
-    for (vector<TSK_DB_FS_INFO>::iterator curFsDbInfo = m_savedFsInfo.begin(); curFsDbInfo!= m_savedFsInfo.end(); ++curFsDbInfo) {
-        if (m_stopAllProcessing)
-            break;
-
-        // finds VS related to the FS
-        TSK_DB_VS_INFO curVsDbInfo;
-        if(getVsByFsId(curFsDbInfo->objId, curVsDbInfo) == TSK_ERR){
-            // FS is not inside a VS
-            if (tsk_verbose) {
-                tsk_fprintf(stderr, "TskAutoDbJava::addUnallocFsSpaceToDb: FS not inside a VS, adding the unnalocated space\n");
-            }
-            TSK_RETVAL_ENUM retval = addFsInfoUnalloc(m_img_info, *curFsDbInfo);
-            if (retval == TSK_ERR)
-                    allFsProcessRet = TSK_ERR;
-        }
-        else {
-            if ((curVsDbInfo.vstype == TSK_VS_TYPE_APFS)||(curVsDbInfo.vstype == TSK_VS_TYPE_LVM)){
-
-                TSK_DB_OBJECT fsObjInfo;
-                if (m_db->getObjectInfo ( curFsDbInfo->objId, fsObjInfo) == TSK_ERR ) {
-                    tsk_error_set_errstr(
-                            "TskAutoDb::addUnallocFsSpaceToDb: error getting Object by ID"
-                            );
-                    tsk_error_set_errno(TSK_ERR_AUTO);
-                    registerError();
-                    return TSK_ERR;
-
-                }
-
-                TSK_VS_PART_INFO curVsPartInfo;
-                if (getVsPartById(fsObjInfo.parObjId, curVsPartInfo) == TSK_ERR){
-                    tsk_error_set_errstr(
-                        "TskAutoDb::addUnallocFsSpaceToDb: error getting Volume Part from FSInfo"
-                        );
-                    tsk_error_set_errno(TSK_ERR_AUTO);
-                    registerError();
-                    return TSK_ERR;
-                }
-
-
-
-
-                if (curVsDbInfo.vstype == TSK_VS_TYPE_APFS) {
-                        const auto pool = tsk_pool_open_img_sing(m_img_info, curVsDbInfo.offset, TSK_POOL_TYPE_APFS);
-                        if (pool == nullptr) {
-                            tsk_error_set_errstr2(
-                                "TskAutoDb::addUnallocFsSpaceToDb:: Error opening pool. ");
-                            tsk_error_set_errstr2("Offset: %" PRIdOFF, curVsDbInfo.offset);
-                            registerError();
-                            allFsProcessRet = TSK_ERR;
-                        }
-                        const auto pool_img = pool->get_img_info(pool, curVsPartInfo.start);
-
-                        if (pool_img != NULL) {
-                            TSK_FS_INFO *fs_info = apfs_open(pool_img, 0, TSK_FS_TYPE_APFS, "");
-                            if (fs_info) {
-                                TSK_RETVAL_ENUM retval = addFsInfoUnalloc(pool_img, *curFsDbInfo);
-                                if (retval == TSK_ERR)
-                                                allFsProcessRet = TSK_ERR;
-
-                                tsk_fs_close(fs_info);
-                                tsk_img_close(pool_img);
-
-                                if (retval == TSK_STOP) {
-                                    tsk_pool_close(pool);
-                                    allFsProcessRet = TSK_STOP;
-                                }
-
-
-                            }
-                            else {
-                                if (pool->vol_list->flags & TSK_POOL_VOLUME_FLAG_ENCRYPTED) {
-                                    tsk_error_reset();
-                                    tsk_error_set_errno(TSK_ERR_FS_ENCRYPTED);
-                                    tsk_error_set_errstr(
-                                        "TskAutoDb::addUnallocFsSpaceToDb: Encrypted APFS file system");
-                                    tsk_error_set_errstr2("Block: %" PRIdOFF, curVsPartInfo.start);
-                                    registerError();
-                                }
-                                else {
-                                    tsk_error_set_errstr2(
-                                        "TskAutoDb::addUnallocFsSpaceToDb: Error opening APFS file system");
-                                    registerError();
-                                }
-
-                                tsk_img_close(pool_img);
-                                tsk_pool_close(pool);
-                                allFsProcessRet = TSK_ERR;
-                            }
-                            tsk_img_close(pool_img);
-                        }
-                        else {
-                            tsk_pool_close(pool);
-                            tsk_error_set_errstr2(
-                                "TskAutoDb::addUnallocFsSpaceToDb: Error opening APFS pool");
-                            registerError();
-                            allFsProcessRet = TSK_ERR;
-                        }
-
-                }
-                #ifdef HAVE_LIBVSLVM
-                if ( curVsDbInfo.vstype == TSK_VS_TYPE_LVM) {
-
-                    const auto pool = tsk_pool_open_img_sing(m_img_info, curVsDbInfo.offset, TSK_POOL_TYPE_LVM);
-                    if (pool == nullptr) {
-                        tsk_error_set_errstr2(
-                        "findFilesInPool: Error opening pool");
-                        registerError();
-                        allFsProcessRet = TSK_ERR;
-                    }
-
-
-                    TSK_IMG_INFO *pool_vol_img = pool->get_img_info(pool, curVsPartInfo.start);
-                    if (pool_vol_img == NULL) {
-                        tsk_pool_close(pool);
-                        tsk_error_set_errstr2(
-                            "TskAutoDb::addUnallocFsSpaceToDb: Error opening LVM logical volume: %" PRIdOFF "",
-                            curVsPartInfo.start);
-                        tsk_error_set_errno(TSK_ERR_FS);
-                        registerError();
-                        allFsProcessRet = TSK_ERR;
-                    }
-                    else {
-                        TSK_FS_INFO *fs_info = tsk_fs_open_img(pool_vol_img, 0, curFsDbInfo->fType);
-                        if (fs_info == NULL) {
-                            tsk_img_close(pool_vol_img);
-                            tsk_pool_close(pool);
-                            tsk_error_set_errstr2(
-                                "findFilesInPool: Unable to open file system in LVM logical volume: %" PRIdOFF "",
-                                curVsPartInfo.start);
-                            tsk_error_set_errno(TSK_ERR_FS);
-                            registerError();
-                            allFsProcessRet = TSK_ERR;
-                        }
-                        else {
-                            TSK_RETVAL_ENUM retval = addFsInfoUnalloc(pool_vol_img, *curFsDbInfo);
-                            if (retval == TSK_ERR){
-                                tsk_error_set_errstr2(
-                                        "TskAutoDb::addUnallocFsSpaceToDb: Error getting unallocated space");
-                                tsk_error_set_errno(TSK_ERR_FS);
-                                registerError();
-                                allFsProcessRet = TSK_ERR;
-                            }
-
-                            tsk_fs_close(fs_info);
-                            tsk_img_close(pool_vol_img);
-
-                            if (retval == TSK_STOP) {
-                                tsk_pool_close(pool);
-                                allFsProcessRet = TSK_STOP;
-                            }
-                        }
-                    }
-
-                }
-                #endif /* HAVE_LIBVSLVM */
-
-                if (curVsDbInfo.vstype == TSK_VS_TYPE_UNSUPP){
-                    tsk_error_set_errstr2(
-                        "TskAutoDb::addUnallocFsSpaceToDb: VS Type not supported");
-                    registerError();
-                    allFsProcessRet = TSK_ERR;
-                }
-            }
-            else {
-                if (addFsInfoUnalloc(m_img_info, *curFsDbInfo) == TSK_ERR){
-                    allFsProcessRet = TSK_ERR;
-                }
-            }
-        }
+    uint16_t ret = m_db->getFsInfos(m_curImgId, fsInfos);
+    if (ret) {
+        tsk_error_set_errstr2("addUnallocFsSpaceToDb: error getting fs infos from db");
+        registerError();
+        return TSK_ERR;
     }
+
+    numFs = fsInfos.size();
+
+    TSK_RETVAL_ENUM allFsProcessRet = TSK_OK;
+    for (vector<TSK_DB_FS_INFO>::iterator it = fsInfos.begin(); it!= fsInfos.end(); ++it) {
+        if (m_stopAllProcessing) {
+            break;
+        }
+        if (addFsInfoUnalloc(*it) == TSK_ERR)
+            allFsProcessRet = TSK_ERR;
+    }
+
+    //TODO set parent_path for newly created virt dir/file hierarchy for consistency
+
     return allFsProcessRet;
 }
 
-
 /**
-* Process each volume in the database and add its unallocated sectors to virtual files.
+* Process each volume in the database and add its unallocated sectors to virtual files. 
 * @param numVsP (out) number of vs partitions found
 * @returns TSK_OK on success, TSK_ERR on error
 */
@@ -1557,7 +1278,7 @@ TSK_RETVAL_ENUM TskAutoDb::addUnallocVsSpaceToDb(size_t & numVsP) {
                    break;
                }
             }
-
+        
             if (hasFs == true) {
                 //skip processing this vspart
                 continue;
@@ -1580,7 +1301,7 @@ TSK_RETVAL_ENUM TskAutoDb::addUnallocVsSpaceToDb(size_t & numVsP) {
         //get sector size and image offset from parent vs info
 
         //get parent id of this vs part
-        TSK_DB_OBJECT vsPartObj;
+        TSK_DB_OBJECT vsPartObj;     
         if (m_db->getObjectInfo(vsPart.objId, vsPartObj) == TSK_ERR) {
             stringstream errss;
             errss << "addUnallocVsSpaceToDb: error getting object info for vs part from db, objId: " << vsPart.objId;
@@ -1600,7 +1321,7 @@ TSK_RETVAL_ENUM TskAutoDb::addUnallocVsSpaceToDb(size_t & numVsP) {
 
         //create an unalloc file (or files) with unalloc part, with vs part as parent
         const uint64_t byteStart = vsInfo.offset + vsInfo.block_size * vsPart.start;
-        const uint64_t byteLen = vsInfo.block_size * vsPart.len;
+        const uint64_t byteLen = vsInfo.block_size * vsPart.len; 
         if (addUnallocBlockFileInChunks(byteStart, byteLen, vsPart.objId, m_curImgId) == TSK_ERR) {
             registerError();
             return TSK_ERR;
@@ -1633,7 +1354,7 @@ TSK_RETVAL_ENUM TskAutoDb::addUnallocImageSpaceToDb() {
 
 /**
 * Adds unallocated block files to the database, chunking if enabled.
-*
+* 
 * @returns TSK_OK on success, TSK_ERR on error
 */
 TSK_RETVAL_ENUM TskAutoDb::addUnallocBlockFileInChunks(uint64_t byteStart, TSK_OFF_T totalSize, int64_t parentObjId, int64_t dataSourceObjId) {
@@ -1664,7 +1385,7 @@ TSK_RETVAL_ENUM TskAutoDb::addUnallocBlockFileInChunks(uint64_t byteStart, TSK_O
             bytesLeft -= maxChunkSize;
         }
 
-        TSK_DB_FILE_LAYOUT_RANGE tempRange(startingOffset, chunkSize, 0);
+        TSK_DB_FILE_LAYOUT_RANGE tempRange(startingOffset, chunkSize, 0);     
         ranges.push_back(tempRange);
         int64_t fileObjId = 0;
 
